# Generated by ariadne-codegen
# Source: queries.gql

from typing import Optional

from .base_model import BaseModel


class Currency(BaseModel):
    currency: Optional["CurrencyCurrency"]


class CurrencyCurrency(BaseModel):
    id: int
    name: str
    iso_code: str
    fractional_unit: Optional[str]
    number_to_basic: Optional[int]



# Generated by ariadne-codegen
# Source: queries.gql

from typing import Optional

from pydantic import Field

from .base_model import BaseModel


class StartCalculations(BaseModel):
    start_calculations: "StartCalculationsStartCalculations" = Field(
        alias="startCalculations"
    )


class StartCalculationsStartCalculations(BaseModel):
    success: bool
    error: Optional[str]



# Generated by ariadne-codegen
# Source: queries.gql

from typing import Optional

from pydantic import Field

from .base_model import BaseModel


class UpdateSecurityQuotes(BaseModel):
    update_security_quotes: "UpdateSecurityQuotesUpdateSecurityQuotes" = Field(
        alias="updateSecurityQuotes"
    )


class UpdateSecurityQuotesUpdateSecurityQuotes(BaseModel):
    success: bool
    error: Optional[str]



# Generated by ariadne-codegen
# Source: queries.gql

from typing import Optional

from pydantic import Field

from .base_model import BaseModel


class UpdateSplits(BaseModel):
    update_splits: "UpdateSplitsUpdateSplits" = Field(alias="updateSplits")


class UpdateSplitsUpdateSplits(BaseModel):
    success: bool
    error: Optional[str]



# Generated by ariadne-codegen
# Source: queries.gql

from typing import Optional

from pydantic import Field

from .base_model import BaseModel


class UpdateSecurity(BaseModel):
    update_security: "UpdateSecurityUpdateSecurity" = Field(alias="updateSecurity")


class UpdateSecurityUpdateSecurity(BaseModel):
    success: bool
    error: Optional[str]



# Generated by ariadne-codegen

"""
 @copyright Copyright (C) 2024 Dennis Greguhn <dev@greguhn.de>
 
 @author Dennis Greguhn <dev@greguhn.de>
 
 @license AGPL-3.0-or-later
 
 This program is free software: you can redistribute it and/or modify
 it under the terms of the GNU Affero General Public License as
 published by the Free Software Foundation, either version 3 of the
 License, or (at your option) any later version.
 
 This program is distributed in the hope that it will be useful,
 but WITHOUT ANY WARRANTY; without even the implied warranty of
 MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 GNU Affero General Public License for more details.
 
 You should have received a copy of the GNU Affero General Public License
 along with this program.  If not, see <http://www.gnu.org/licenses/>.
"""

from ariadne import ScalarType
import json
from decimal import Decimal
from datetime import date, time


class CustomEncoder(json.JSONEncoder):
	"""Custom JSON encoder to convert Decimal and time/date types
	"""
	def default(self, obj):
		if isinstance(obj, Decimal):
			return str(obj)
		elif isinstance(obj, date) or isinstance(obj, time):
			return obj.isoformat()
		# Base class
		return super().default(obj)


def serializer(value:dict) -> dict:
	"""Serializer for custom GrapQL scalar **JSON**

	Args:
		value (dict): Dictionary object to convert

	Raises:
		ValueError: Error if invalid JSON

	Returns:
		dict: Dict/JSON with converted decimal and time/date
	"""
	try:
		return json.loads(json.dumps(value, cls=CustomEncoder))
	except (ValueError, TypeError):
		raise ValueError(f'"{value}" is not a valid JSON string')


def value_parser(value:dict) -> dict:
	return value


jsonScalar = ScalarType('JSON', serializer=serializer, value_parser=value_parser)


# Generated by ariadne-codegen
# Source: http://localhost:8042/graphql/

from enum import Enum


class SecurityType(str, Enum):
    Stock = "Stock"
    ETF = "ETF"


class DividendPeriod(str, Enum):
    Weekly = "Weekly"
    Monthly = "Monthly"
    SemiAnnual = "SemiAnnual"
    Quarterly = "Quarterly"
    Annual = "Annual"
    Other = "Other"



# Generated by ariadne-codegen
# Source: http://localhost:8042/graphql/

from datetime import date, datetime
from decimal import Decimal
from typing import Annotated, List, Optional

from pydantic import Field, PlainSerializer

from .base_model import BaseModel
from .bigint_scalar import serializer
from .date_scalar import serializer
from .datetime_scalar import serializer
from .decimal_scalar import serializer
from .enums import DividendPeriod, SecurityType


class SecurityInput(BaseModel):
    code: str
    type: Optional[SecurityType] = None
    name: Optional[str] = None
    exchange_code: str
    currency_iso_code: Optional[str] = None
    country_alpha_3: Optional[str] = Field(alias="country_alpha3", default=None)
    last_update: Annotated[datetime, PlainSerializer(serializer)]
    figi: Optional[str] = None
    isin: Optional[str] = None
    lei: Optional[str] = None
    wkn: Optional[str] = None
    cusip: Optional[str] = None
    cik: Optional[str] = None
    tws_con_id: Optional[Annotated[int, PlainSerializer(serializer)]] = None
    ipo_date: Optional[Annotated[date, PlainSerializer(serializer)]] = None
    is_delisted: Optional[bool] = None
    delisting_date: Optional[Annotated[date, PlainSerializer(serializer)]] = None
    description: Optional[str] = None
    marketcap: Optional[Annotated[int, PlainSerializer(serializer)]] = None
    beta: Optional[Annotated[Decimal, PlainSerializer(serializer)]] = None
    shares_outstanding: Optional[Annotated[int, PlainSerializer(serializer)]] = None
    shares_float: Optional[Annotated[int, PlainSerializer(serializer)]] = None
    shares_short: Optional[Annotated[int, PlainSerializer(serializer)]] = None
    short_ratio: Optional[Annotated[Decimal, PlainSerializer(serializer)]] = None
    short_percent_outstanding: Optional[
        Annotated[Decimal, PlainSerializer(serializer)]
    ] = None
    short_percent_float: Optional[
        Annotated[Decimal, PlainSerializer(serializer)]
    ] = None
    has_options: Optional[bool] = None
    url: Optional[str] = None
    gics_code: Optional[int] = None
    sector: Optional[str] = None
    industry: Optional[str] = None
    logo_url: Optional[str] = None
    logo_base_64: Optional[str] = Field(alias="logo_base64", default=None)
    ebitda: Optional[Annotated[int, PlainSerializer(serializer)]] = None
    pe_ratio: Optional[Annotated[Decimal, PlainSerializer(serializer)]] = None
    wallstreet_target_price: Optional[
        Annotated[Decimal, PlainSerializer(serializer)]
    ] = None
    book_value: Optional[Annotated[Decimal, PlainSerializer(serializer)]] = None
    dividend_share: Optional[Annotated[Decimal, PlainSerializer(serializer)]] = None
    dividend_yield: Optional[Annotated[Decimal, PlainSerializer(serializer)]] = None
    earnings_share: Optional[Annotated[Decimal, PlainSerializer(serializer)]] = None
    eps_estimate_current_year: Optional[
        Annotated[Decimal, PlainSerializer(serializer)]
    ] = None
    eps_estimate_next_year: Optional[
        Annotated[Decimal, PlainSerializer(serializer)]
    ] = None
    eps_estimate_next_quarter: Optional[
        Annotated[Decimal, PlainSerializer(serializer)]
    ] = None
    eps_estimate_current_quarter: Optional[
        Annotated[Decimal, PlainSerializer(serializer)]
    ] = None
    most_recent_quarter: Optional[Annotated[date, PlainSerializer(serializer)]] = None
    profit_margin: Optional[Annotated[Decimal, PlainSerializer(serializer)]] = None
    operating_margin_ttm: Optional[
        Annotated[Decimal, PlainSerializer(serializer)]
    ] = None
    return_on_assets_ttm: Optional[
        Annotated[Decimal, PlainSerializer(serializer)]
    ] = None
    return_on_equity_ttm: Optional[
        Annotated[Decimal, PlainSerializer(serializer)]
    ] = None
    revenue_ttm: Optional[Annotated[int, PlainSerializer(serializer)]] = None
    revenue_per_share_ttm: Optional[
        Annotated[Decimal, PlainSerializer(serializer)]
    ] = None
    quarterly_revenue_growth_yoy: Optional[
        Annotated[Decimal, PlainSerializer(serializer)]
    ] = None
    gross_profit_ttm: Optional[Annotated[int, PlainSerializer(serializer)]] = None
    diluted_eps_ttm: Optional[Annotated[Decimal, PlainSerializer(serializer)]] = None
    quarterly_earnings_growth_yoy: Optional[
        Annotated[Decimal, PlainSerializer(serializer)]
    ] = None
    forward_pe: Optional[Annotated[Decimal, PlainSerializer(serializer)]] = None
    price_sales_ttm: Optional[Annotated[Decimal, PlainSerializer(serializer)]] = None
    price_book_mrq: Optional[Annotated[Decimal, PlainSerializer(serializer)]] = None
    enterprise_value: Optional[Annotated[int, PlainSerializer(serializer)]] = None
    enterprise_value_revenue: Optional[
        Annotated[Decimal, PlainSerializer(serializer)]
    ] = None
    enterprise_value_ebitda: Optional[
        Annotated[Decimal, PlainSerializer(serializer)]
    ] = None


class SecurityQuoteData(BaseModel):
    date: Annotated[date, PlainSerializer(serializer)]
    open: Optional[Annotated[Decimal, PlainSerializer(serializer)]] = None
    high: Optional[Annotated[Decimal, PlainSerializer(serializer)]] = None
    low: Optional[Annotated[Decimal, PlainSerializer(serializer)]] = None
    close: Optional[Annotated[Decimal, PlainSerializer(serializer)]] = None
    split_adjusted_open: Optional[
        Annotated[Decimal, PlainSerializer(serializer)]
    ] = None
    split_adjusted_high: Optional[
        Annotated[Decimal, PlainSerializer(serializer)]
    ] = None
    split_adjusted_low: Optional[Annotated[Decimal, PlainSerializer(serializer)]] = None
    split_adjusted_close: Optional[
        Annotated[Decimal, PlainSerializer(serializer)]
    ] = None
    adjusted_close: Optional[Annotated[Decimal, PlainSerializer(serializer)]] = None
    volume: Optional[Annotated[Decimal, PlainSerializer(serializer)]] = None


class SecurityQuotesInput(BaseModel):
    code: str
    exchange_code: str
    quotes: List["SecurityQuoteData"]


class SplitData(BaseModel):
    date: Annotated[date, PlainSerializer(serializer)]
    old: Optional[Annotated[Decimal, PlainSerializer(serializer)]] = None
    new: Optional[Annotated[Decimal, PlainSerializer(serializer)]] = None


class SplitsInput(BaseModel):
    code: str
    exchange_code: str
    splits: List["SplitData"]


class DividendData(BaseModel):
    date: Annotated[date, PlainSerializer(serializer)]
    declaration_date: Optional[Annotated[date, PlainSerializer(serializer)]] = None
    record_date: Optional[Annotated[date, PlainSerializer(serializer)]] = None
    payment_date: Optional[Annotated[date, PlainSerializer(serializer)]] = None
    period: Optional[DividendPeriod] = None
    adjusted_value: Optional[Annotated[Decimal, PlainSerializer(serializer)]] = None
    value: Optional[Annotated[Decimal, PlainSerializer(serializer)]] = None


class DividendsInput(BaseModel):
    code: str
    exchange_code: str
    dividends: List["DividendData"]


class AnalystRatingsData(BaseModel):
    date_added: Optional[Annotated[date, PlainSerializer(serializer)]] = None
    rating: Optional[Annotated[Decimal, PlainSerializer(serializer)]] = None
    target_price: Optional[Annotated[Decimal, PlainSerializer(serializer)]] = None
    strong_buy: Optional[int] = None
    buy: Optional[int] = None
    hold: Optional[int] = None
    sell: Optional[int] = None
    strong_sell: Optional[int] = None


class AnalystRatingsInput(BaseModel):
    code: str
    exchange_code: str
    analyst_ratings: List["AnalystRatingsData"]


class InsiderTransactionsData(BaseModel):
    date: Annotated[date, PlainSerializer(serializer)]
    report_date: Optional[Annotated[date, PlainSerializer(serializer)]] = None
    owner_cik: Optional[str] = None
    owner_name: str
    owner_relationship: Optional[str] = None
    owner_title: Optional[str] = None
    transaction_date: Annotated[date, PlainSerializer(serializer)]
    transaction_code: str
    transaction_amount: Annotated[int, PlainSerializer(serializer)]
    transaction_price: Annotated[Decimal, PlainSerializer(serializer)]
    transaction_acquired_disposed: Optional[str] = None
    post_transaction_amount: Optional[
        Annotated[int, PlainSerializer(serializer)]
    ] = None
    sec_link: Optional[str] = None


class InsiderTransactionsInput(BaseModel):
    code: str
    exchange_code: str
    insider_transactions: List["InsiderTransactionsData"]


class OutstandingShareData(BaseModel):
    date: Annotated[date, PlainSerializer(serializer)]
    outstanding_shares: Optional[Annotated[int, PlainSerializer(serializer)]] = None


class OutstandingSharesInput(BaseModel):
    code: str
    exchange_code: str
    outstanding_shares: List["OutstandingShareData"]



# Generated by ariadne-codegen
# Source: queries.gql

from typing import Optional

from pydantic import Field

from .base_model import BaseModel


class UpdateOutstandingShares(BaseModel):
    update_outstanding_shares: "UpdateOutstandingSharesUpdateOutstandingShares" = Field(
        alias="updateOutstandingShares"
    )


class UpdateOutstandingSharesUpdateOutstandingShares(BaseModel):
    success: bool
    error: Optional[str]



import asyncio
from ascentrade_client import AscentradeClient

async def main():
	client = AscentradeClient("http://localhost:8042/graphql/")

	data = await client.currencies()
	for c in data.currencies:
		print(f'{c.id}: {c.name} ({c.iso_code})')


if __name__ == '__main__':
	asyncio.run(main())


# Generated by ariadne-codegen
# Source: queries.gql

from datetime import datetime
from typing import Annotated, List, Optional

from pydantic import BeforeValidator

from .base_model import BaseModel
from .datetime_scalar import value_parser


class AllSecurityTickers(BaseModel):
    securities: List[Optional["AllSecurityTickersSecurities"]]


class AllSecurityTickersSecurities(BaseModel):
    id: int
    code: str
    last_update: Annotated[datetime, BeforeValidator(value_parser)]
    is_delisted: Optional[bool]
    exchange: "AllSecurityTickersSecuritiesExchange"


class AllSecurityTickersSecuritiesExchange(BaseModel):
    code: str
    virtual_exchange: Optional[str]



# Generated by ariadne-codegen

"""
 @copyright Copyright (C) 2024 Dennis Greguhn <dev@greguhn.de>
 
 @author Dennis Greguhn <dev@greguhn.de>
 
 @license AGPL-3.0-or-later
 
 This program is free software: you can redistribute it and/or modify
 it under the terms of the GNU Affero General Public License as
 published by the Free Software Foundation, either version 3 of the
 License, or (at your option) any later version.
 
 This program is distributed in the hope that it will be useful,
 but WITHOUT ANY WARRANTY; without even the implied warranty of
 MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 GNU Affero General Public License for more details.
 
 You should have received a copy of the GNU Affero General Public License
 along with this program.  If not, see <http://www.gnu.org/licenses/>.
"""

# 3.14159
from ariadne import ScalarType
from decimal import Decimal


def serializer(value:Decimal) -> str:
	"""Serializer for custom GrapQL scalar **Decimal**

	Args:
		value (Decimal): Decimal value

	Raises:
		ValueError: If string conversion fails

	Returns:
		str: Decimal number string
	"""
	try:
		return str(value)
	except (ValueError, TypeError):
		raise ValueError(f'"{value}" is not a valid decimal')


def value_parser(value:str) -> Decimal:
	"""Value parser for custom GrapQL scalar **Decimal**

	Args:
		value (str): String representation of decimal number

	Raises:
		ValueError: If conversion to Decimal fails

	Returns:
		Decimal: Decimal type
	"""
	try:
		return Decimal(value)
	except (ValueError, TypeError):
		raise ValueError(f'"{value}" is not a valid decimal')


decimalScalar = ScalarType('Decimal', serializer=serializer, value_parser=value_parser)


# Generated by ariadne-codegen

"""
 @copyright Copyright (C) 2024 Dennis Greguhn <dev@greguhn.de>
 
 @author Dennis Greguhn <dev@greguhn.de>
 
 @license AGPL-3.0-or-later
 
 This program is free software: you can redistribute it and/or modify
 it under the terms of the GNU Affero General Public License as
 published by the Free Software Foundation, either version 3 of the
 License, or (at your option) any later version.
 
 This program is distributed in the hope that it will be useful,
 but WITHOUT ANY WARRANTY; without even the implied warranty of
 MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 GNU Affero General Public License for more details.
 
 You should have received a copy of the GNU Affero General Public License
 along with this program.  If not, see <http://www.gnu.org/licenses/>.
"""

# 2023-08-02
from ariadne import ScalarType
from datetime import date


def serializer(value:date) -> str:
	"""Serializer for custom GrapQL scalar **Date**

	Args:
		value (date): datetime.date object

	Raises:
		ValueError: If no valid date

	Returns:
		str: String with parsed date in ISO format like 2024-01-12
	"""
	try:
		return value.isoformat()
	except (ValueError, TypeError):
		raise ValueError(f'"{value}" is not a valid date')


def value_parser(value:str) -> date:
	"""Value parser for custom GrapQL scalar **Date**

	Args:
		value (str): String of ISO formatted date

	Raises:
		ValueError: If no valid string in ISO format

	Returns:
		date: Parsed datetime.date object
	"""
	try:
		return  date.fromisoformat(value)
	except (ValueError, TypeError):
		raise ValueError(f'"{value}" is not a valid ISO date string')


dateScalar = ScalarType('Date', serializer=serializer, value_parser=value_parser)


# Generated by ariadne-codegen
# Source: queries.gql

from typing import List, Optional

from pydantic import Field

from .base_model import BaseModel
from .enums import SecurityType


class SearchSecurity(BaseModel):
    search_security: List[Optional["SearchSecuritySearchSecurity"]] = Field(
        alias="searchSecurity"
    )


class SearchSecuritySearchSecurity(BaseModel):
    id: int
    code: str
    name: str
    type: SecurityType



# Generated by ariadne-codegen
# Source: queries.gql

from typing import Annotated, Optional

from pydantic import BeforeValidator

from .base_model import BaseModel
from .json_scalar import value_parser


class Security(BaseModel):
    security: Optional["SecuritySecurity"]


class SecuritySecurity(BaseModel):
    name: str
    indicators: Optional[Annotated[dict, BeforeValidator(value_parser)]]



# Generated by ariadne-codegen
# Source: queries.gql

from typing import Any, Dict, Optional, Union

from .all_security_tickers import AllSecurityTickers
from .async_base_client_open_telemetry import AsyncBaseClientOpenTelemetry
from .base_model import UNSET, UnsetType
from .currencies import Currencies
from .currency import Currency
from .exchanges import Exchanges
from .input_types import (
    DividendsInput,
    OutstandingSharesInput,
    SecurityInput,
    SecurityQuotesInput,
    SplitsInput,
)
from .ping import Ping
from .search_security import SearchSecurity
from .security import Security
from .update_dividends import UpdateDividends
from .update_outstanding_shares import UpdateOutstandingShares
from .update_security import UpdateSecurity
from .update_security_quotes import UpdateSecurityQuotes
from .update_splits import UpdateSplits


def gql(q: str) -> str:
    return q


class AscentradeClient(AsyncBaseClientOpenTelemetry):
    async def ping(self, **kwargs: Any) -> Ping:
        query = gql(
            """
            query Ping {
              ping
            }
            """
        )
        variables: Dict[str, object] = {}
        response = await self.execute(
            query=query, operation_name="Ping", variables=variables, **kwargs
        )
        data = self.get_data(response)
        return Ping.model_validate(data)

    async def currencies(self, **kwargs: Any) -> Currencies:
        query = gql(
            """
            query Currencies {
              currencies {
                id
                name
                iso_code
                fractional_unit
                number_to_basic
              }
            }
            """
        )
        variables: Dict[str, object] = {}
        response = await self.execute(
            query=query, operation_name="Currencies", variables=variables, **kwargs
        )
        data = self.get_data(response)
        return Currencies.model_validate(data)

    async def currency(self, id: int, **kwargs: Any) -> Currency:
        query = gql(
            """
            query Currency($id: Int!) {
              currency(id: $id) {
                id
                name
                iso_code
                fractional_unit
                number_to_basic
              }
            }
            """
        )
        variables: Dict[str, object] = {"id": id}
        response = await self.execute(
            query=query, operation_name="Currency", variables=variables, **kwargs
        )
        data = self.get_data(response)
        return Currency.model_validate(data)

    async def exchanges(self, **kwargs: Any) -> Exchanges:
        query = gql(
            """
            query Exchanges {
              exchanges {
                id
                name
                country {
                  alpha3_code
                  name
                }
                currency {
                  name
                  iso_code
                }
                open_utc
                close_utc
              }
            }
            """
        )
        variables: Dict[str, object] = {}
        response = await self.execute(
            query=query, operation_name="Exchanges", variables=variables, **kwargs
        )
        data = self.get_data(response)
        return Exchanges.model_validate(data)

    async def update_security(
        self, data: SecurityInput, **kwargs: Any
    ) -> UpdateSecurity:
        query = gql(
            """
            mutation UpdateSecurity($data: SecurityInput!) {
              updateSecurity(data: $data) {
                success
                error
              }
            }
            """
        )
        variables: Dict[str, object] = {"data": data}
        response = await self.execute(
            query=query, operation_name="UpdateSecurity", variables=variables, **kwargs
        )
        data = self.get_data(response)
        return UpdateSecurity.model_validate(data)

    async def update_security_quotes(
        self, data: SecurityQuotesInput, **kwargs: Any
    ) -> UpdateSecurityQuotes:
        query = gql(
            """
            mutation UpdateSecurityQuotes($data: SecurityQuotesInput!) {
              updateSecurityQuotes(data: $data) {
                success
                error
              }
            }
            """
        )
        variables: Dict[str, object] = {"data": data}
        response = await self.execute(
            query=query,
            operation_name="UpdateSecurityQuotes",
            variables=variables,
            **kwargs
        )
        data = self.get_data(response)
        return UpdateSecurityQuotes.model_validate(data)

    async def update_splits(self, data: SplitsInput, **kwargs: Any) -> UpdateSplits:
        query = gql(
            """
            mutation UpdateSplits($data: SplitsInput!) {
              updateSplits(data: $data) {
                success
                error
              }
            }
            """
        )
        variables: Dict[str, object] = {"data": data}
        response = await self.execute(
            query=query, operation_name="UpdateSplits", variables=variables, **kwargs
        )
        data = self.get_data(response)
        return UpdateSplits.model_validate(data)

    async def update_dividends(
        self, data: DividendsInput, **kwargs: Any
    ) -> UpdateDividends:
        query = gql(
            """
            mutation UpdateDividends($data: DividendsInput!) {
              updateDividends(data: $data) {
                success
                error
              }
            }
            """
        )
        variables: Dict[str, object] = {"data": data}
        response = await self.execute(
            query=query, operation_name="UpdateDividends", variables=variables, **kwargs
        )
        data = self.get_data(response)
        return UpdateDividends.model_validate(data)

    async def update_outstanding_shares(
        self, data: OutstandingSharesInput, **kwargs: Any
    ) -> UpdateOutstandingShares:
        query = gql(
            """
            mutation UpdateOutstandingShares($data: OutstandingSharesInput!) {
              updateOutstandingShares(data: $data) {
                success
                error
              }
            }
            """
        )
        variables: Dict[str, object] = {"data": data}
        response = await self.execute(
            query=query,
            operation_name="UpdateOutstandingShares",
            variables=variables,
            **kwargs
        )
        data = self.get_data(response)
        return UpdateOutstandingShares.model_validate(data)

    async def security(self, id: int, **kwargs: Any) -> Security:
        query = gql(
            """
            query Security($id: Int!) {
              security(id: $id) {
                name
                indicators
              }
            }
            """
        )
        variables: Dict[str, object] = {"id": id}
        response = await self.execute(
            query=query, operation_name="Security", variables=variables, **kwargs
        )
        data = self.get_data(response)
        return Security.model_validate(data)

    async def all_security_tickers(self, **kwargs: Any) -> AllSecurityTickers:
        query = gql(
            """
            query AllSecurityTickers {
              securities {
                id
                code
                last_update
                is_delisted
                exchange {
                  code
                  virtual_exchange
                }
              }
            }
            """
        )
        variables: Dict[str, object] = {}
        response = await self.execute(
            query=query,
            operation_name="AllSecurityTickers",
            variables=variables,
            **kwargs
        )
        data = self.get_data(response)
        return AllSecurityTickers.model_validate(data)

    async def search_security(
        self,
        search_text: str,
        limit: Union[Optional[int], UnsetType] = UNSET,
        **kwargs: Any
    ) -> SearchSecurity:
        query = gql(
            """
            query SearchSecurity($searchText: String!, $limit: Int) {
              searchSecurity(searchText: $searchText, limit: $limit) {
                id
                code
                name
                type
              }
            }
            """
        )
        variables: Dict[str, object] = {"searchText": search_text, "limit": limit}
        response = await self.execute(
            query=query, operation_name="SearchSecurity", variables=variables, **kwargs
        )
        data = self.get_data(response)
        return SearchSecurity.model_validate(data)



# Generated by ariadne-codegen

"""
 @copyright Copyright (C) 2024 Dennis Greguhn <dev@greguhn.de>
 
 @author Dennis Greguhn <dev@greguhn.de>
 
 @license AGPL-3.0-or-later
 
 This program is free software: you can redistribute it and/or modify
 it under the terms of the GNU Affero General Public License as
 published by the Free Software Foundation, either version 3 of the
 License, or (at your option) any later version.
 
 This program is distributed in the hope that it will be useful,
 but WITHOUT ANY WARRANTY; without even the implied warranty of
 MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 GNU Affero General Public License for more details.
 
 You should have received a copy of the GNU Affero General Public License
 along with this program.  If not, see <http://www.gnu.org/licenses/>.
"""

# 12345678910111213
from ariadne import ScalarType

def serializer(value:int) -> str:
	"""Serializer for custom GrapQL scalar **BigInt**

	Args:
		value (int): Python integer value

	Raises:
		ValueError: Error if invalid BigInt

	Returns:
		str: String with BigInt representation (string of int)
	"""
	try:
		return str(value)
	except (ValueError, TypeError):
		raise ValueError(f'"{value}" is not a valid integer')


def value_parser(value:str) -> int:
	"""Value parser for custom GrapQL scalar **BigInt**

	Args:
		value (str): String with BigInt representation

	Raises:
		ValueError: Error if invalid string

	Returns:
		int: Converted BigInt object
	"""
	try:
		return int(value)
	except (ValueError, TypeError):
		raise ValueError(f'"{value}" is not a valid BigInt string')


bigintScalar = ScalarType('BigInt', serializer=serializer, value_parser=value_parser)


# Generated by ariadne-codegen
# Source: queries.gql

from datetime import time
from typing import Annotated, List, Optional

from pydantic import BeforeValidator, Field

from .base_model import BaseModel
from .time_scalar import value_parser


class Exchanges(BaseModel):
    exchanges: List[Optional["ExchangesExchanges"]]


class ExchangesExchanges(BaseModel):
    id: int
    name: str
    country: Optional["ExchangesExchangesCountry"]
    currency: Optional["ExchangesExchangesCurrency"]
    open_utc: Optional[Annotated[time, BeforeValidator(value_parser)]]
    close_utc: Optional[Annotated[time, BeforeValidator(value_parser)]]


class ExchangesExchangesCountry(BaseModel):
    alpha_3_code: str = Field(alias="alpha3_code")
    name: str


class ExchangesExchangesCurrency(BaseModel):
    name: str
    iso_code: str



# Generated by ariadne-codegen

from .all_security_tickers import (
    AllSecurityTickers,
    AllSecurityTickersSecurities,
    AllSecurityTickersSecuritiesExchange,
)
from .async_base_client_open_telemetry import AsyncBaseClientOpenTelemetry
from .base_model import BaseModel, Upload
from .client import AscentradeClient
from .currencies import Currencies, CurrenciesCurrencies
from .currency import Currency, CurrencyCurrency
from .enums import DividendPeriod, SecurityType
from .exceptions import (
    GraphQLClientError,
    GraphQLClientGraphQLError,
    GraphQLClientGraphQLMultiError,
    GraphQLClientHttpError,
    GraphQLClientInvalidResponseError,
)
from .exchanges import (
    Exchanges,
    ExchangesExchanges,
    ExchangesExchangesCountry,
    ExchangesExchangesCurrency,
)
from .input_types import (
    AnalystRatingsData,
    AnalystRatingsInput,
    DividendData,
    DividendsInput,
    InsiderTransactionsData,
    InsiderTransactionsInput,
    OutstandingShareData,
    OutstandingSharesInput,
    SecurityInput,
    SecurityQuoteData,
    SecurityQuotesInput,
    SplitData,
    SplitsInput,
)
from .ping import Ping
from .search_security import SearchSecurity, SearchSecuritySearchSecurity
from .security import Security, SecuritySecurity
from .update_dividends import UpdateDividends, UpdateDividendsUpdateDividends
from .update_outstanding_shares import (
    UpdateOutstandingShares,
    UpdateOutstandingSharesUpdateOutstandingShares,
)
from .update_security import UpdateSecurity, UpdateSecurityUpdateSecurity
from .update_security_quotes import (
    UpdateSecurityQuotes,
    UpdateSecurityQuotesUpdateSecurityQuotes,
)
from .update_splits import UpdateSplits, UpdateSplitsUpdateSplits

__all__ = [
    "AllSecurityTickers",
    "AllSecurityTickersSecurities",
    "AllSecurityTickersSecuritiesExchange",
    "AnalystRatingsData",
    "AnalystRatingsInput",
    "AscentradeClient",
    "AsyncBaseClientOpenTelemetry",
    "BaseModel",
    "Currencies",
    "CurrenciesCurrencies",
    "Currency",
    "CurrencyCurrency",
    "DividendData",
    "DividendPeriod",
    "DividendsInput",
    "Exchanges",
    "ExchangesExchanges",
    "ExchangesExchangesCountry",
    "ExchangesExchangesCurrency",
    "GraphQLClientError",
    "GraphQLClientGraphQLError",
    "GraphQLClientGraphQLMultiError",
    "GraphQLClientHttpError",
    "GraphQLClientInvalidResponseError",
    "InsiderTransactionsData",
    "InsiderTransactionsInput",
    "OutstandingShareData",
    "OutstandingSharesInput",
    "Ping",
    "SearchSecurity",
    "SearchSecuritySearchSecurity",
    "Security",
    "SecurityInput",
    "SecurityQuoteData",
    "SecurityQuotesInput",
    "SecuritySecurity",
    "SecurityType",
    "SplitData",
    "SplitsInput",
    "UpdateDividends",
    "UpdateDividendsUpdateDividends",
    "UpdateOutstandingShares",
    "UpdateOutstandingSharesUpdateOutstandingShares",
    "UpdateSecurity",
    "UpdateSecurityQuotes",
    "UpdateSecurityQuotesUpdateSecurityQuotes",
    "UpdateSecurityUpdateSecurity",
    "UpdateSplits",
    "UpdateSplitsUpdateSplits",
    "Upload",
]



# Generated by ariadne-codegen
# Source: queries.gql

from typing import List, Optional

from .base_model import BaseModel


class Currencies(BaseModel):
    currencies: List[Optional["CurrenciesCurrencies"]]


class CurrenciesCurrencies(BaseModel):
    id: int
    name: str
    iso_code: str
    fractional_unit: Optional[str]
    number_to_basic: Optional[int]
